BioKEEN
=======
BioKEEN (Python KnowlEdge EmbeddiNgs) is wrapper around `PyKEEN <https://github.com/SmartDataAnalytics/PyKEEN>`_ for
training and evaluating **biological** knowledge graph embeddings.

Installation is as easy as getting the code from `PyPI <https://pypi.python.org/pypi/biokeen>`_ with
:code:`python3 -m pip install biokeen`.

Citation
--------
If you use BioKEEN in your work, please cite [1]_:

.. [1] Ali, M., *et al.* (2018). `BioKEEN: A library for learning and evaluating biological knowledge graph embeddings
       <https://zenodo.org/badge/latestdoi/136345023>`_.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :name: start

   installation

.. toctree::
   :maxdepth: 2
   :caption: Biological Databases
   :name: data

   bio2bel_repositories

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
